*EBD-2 Ch 6 Stata code 2019-0912.do

*EBD-2 Chapter 6 calcs
/* This Stata do-file reproduces calculations and graphs for Chapter 6 of Evidence-Based Diagnosis, 2nd edition.  To do the decision curve analysis you will need to download the decision curve analysis (DCA) ado file, which you can find at 
https://www.mskcc.org/departments/epidemiology-biostatistics/biostatistics/decision-curve-analysis
(as of 9/12/19) or by typing "findit stdca"

Thomas B. Newman, MD, MPH
9/12/19
*/

*******Create empty dataset
clear
set obs 300
gen id=_n
*******Make risk groups
gen group=int((id-1)/100)
tabu group

*******Make outcomes
gen recur=1 if group==0 & id<34
replace recur=1 if group==1 & id <118
replace recur=1 if group==2 & id<212
replace recur=0 if recur==.
tabu recur

*******Make Bleakhaus predictions
gen bpred=0.5 if group==0
replace bpred=0.35 if group==1
replace bpred=.2 if group==2
label variabl bpred "BleakHaus"
tabu bpred

*******Make Agnosia predictions
gen apred=0.20
label variable apred "AgnoSIA"

*******Make PolyAna predictions
gen ppred=0.25 if group==0
replace ppred=0.1 if group==1
replace ppred=.05 if group==2
tabu ppred
label variable ppred "PolyAna"

*******Make Recalibrated predictions
gen rpred=0.33 if group==0
replace rpred=0.17 if group==1
replace rpred=.11 if group==2
tabu rpred
label variable rpred "Recalibrated"

****** Do brier scores
brier recur bpred
brier recur apred
brier recur ppred


****Figure 6.7 Portrait orientation 3 panels 
*Panel A recalibrated
dca recur rpred, xstop(.4) legend(off) lwidth(medium) lpattern(dash) title(A) 

*Panel B Bleakhaus
dca recur bpred, xstop(.4) legend(off) lwidth(medium) lpattern(dash) title(B) 
*Panel C PolyANA
dca recur ppred, xstop(.4) legend(off) lwidth(medium) lpattern(dash) title(C) 
save mastate, replace

*end

